summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/ui/kopetelistviewitem.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit2bc1d72869b62af05ae4feafd878203b526da8c5 (patch)
tree2676903bb600bd9646644856e354940471ad84e2 /kopete/libkopete/ui/kopetelistviewitem.h
parent937b2991d8e78166eea904c80ad04d34607017a4 (diff)
downloadtdenetwork-2bc1d72869b62af05ae4feafd878203b526da8c5.tar.gz
tdenetwork-2bc1d72869b62af05ae4feafd878203b526da8c5.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/libkopete/ui/kopetelistviewitem.h')
-rw-r--r--kopete/libkopete/ui/kopetelistviewitem.h38
1 files changed, 19 insertions, 19 deletions
diff --git a/kopete/libkopete/ui/kopetelistviewitem.h b/kopete/libkopete/ui/kopetelistviewitem.h
index ac19c4b8..0868afab 100644
--- a/kopete/libkopete/ui/kopetelistviewitem.h
+++ b/kopete/libkopete/ui/kopetelistviewitem.h
@@ -102,7 +102,7 @@ public:
class Component : public ComponentBase
{
protected:
- Component( ComponentBase *tqparent );
+ Component( ComponentBase *parent );
public:
virtual ~Component() = 0;
@@ -110,7 +110,7 @@ public:
* Set the size and position of this item relative to the list view item. Should
* only be called by the containing item.
* @param rect the new rectangle this component will paint in, relative to the painter
* passed to the paint() function by the tqparent item.
*/
virtual void tqlayout( const TQRect &rect );
@@ -200,7 +200,7 @@ protected:
* @param width the minimum width
* @return true if the size has actually changed, false if it's been set to
* the existing values. if it returns true, you do not need to retqlayout,
* since the tqparent component will do that for you.
*/
bool setMinWidth( int width );
/**
@@ -209,7 +209,7 @@ protected:
* @param height the minimum height
* @return true if the size has actually changed, false if it's been set to
* the existing values. If it returns true, you do not need to retqlayout,
* since the tqparent component will do that for you.
*/
bool setMinHeight( int height );
@@ -233,7 +233,7 @@ class BoxComponent : public Component
{
public:
enum Direction {Horizontal,Vertical };
- BoxComponent( ComponentBase *tqparent, Direction dir =Horizontal );
+ BoxComponent( ComponentBase *parent, Direction dir =Horizontal );
~BoxComponent();
virtual void tqlayout( const TQRect &rect );
@@ -262,7 +262,7 @@ private:
class ContactBoxComponent : public BoxComponent
{
public:
- ContactBoxComponent(ComponentBase *tqparent, Direction dir =Horizontal);
+ ContactBoxComponent(ComponentBase *parent, Direction dir =Horizontal);
~ContactBoxComponent();
virtual void reloadTheme();
@@ -285,7 +285,7 @@ private:
class GroupBoxComponent : public BoxComponent
{
public:
- GroupBoxComponent(ComponentBase *tqparent, Direction dir =Horizontal);
+ GroupBoxComponent(ComponentBase *parent, Direction dir =Horizontal);
~GroupBoxComponent();
virtual void reloadTheme();
@@ -305,7 +305,7 @@ private:
class TextComponent : public Component
{
public:
- TextComponent( ComponentBase *tqparent, const TQFont &font = TQFont(), const TQString &text = TQString() );
+ TextComponent( ComponentBase *parent, const TQFont &font = TQFont(), const TQString &text = TQString() );
~TextComponent();
TQString text();
@@ -335,8 +335,8 @@ private:
class ImageComponent : public Component
{
public:
- ImageComponent( ComponentBase *tqparent );
- ImageComponent( ComponentBase *tqparent, int minW, int minH );
+ ImageComponent( ComponentBase *parent );
+ ImageComponent( ComponentBase *parent, int minW, int minH );
~ImageComponent();
virtual void setPixmap( const TQPixmap &img, bool adjustSize = true);
@@ -358,8 +358,8 @@ protected:
class FaceComponent : public ImageComponent
{
public:
- FaceComponent(ComponentBase *tqparent): ImageComponent(tqparent) {}
- FaceComponent(ComponentBase *tqparent, int minW, int minH): ImageComponent(tqparent, minH, minW) {}
+ FaceComponent(ComponentBase *parent): ImageComponent(parent) {}
+ FaceComponent(ComponentBase *parent, int minW, int minH): ImageComponent(parent, minH, minW) {}
void setPixmap(const TQPixmap &img, bool adjustSize = true);
void paint(TQPainter *painter, const TQColorGroup &cg);
@@ -371,7 +371,7 @@ public:
class ContactComponent : public ImageComponent
{
public:
- ContactComponent( ComponentBase *tqparent, Kopete::Contact *contact, int iconSize);
+ ContactComponent( ComponentBase *parent, Kopete::Contact *contact, int iconSize);
~ContactComponent();
void updatePixmap();
Kopete::Contact *contact();
@@ -387,7 +387,7 @@ protected:
class SpacerComponent : public Component
{
public:
- SpacerComponent( ComponentBase *tqparent, int w, int h );
+ SpacerComponent( ComponentBase *parent, int w, int h );
};
/**
@@ -400,7 +400,7 @@ public:
/**
* Constructor
*/
- DisplayNameComponent( ComponentBase *tqparent );
+ DisplayNameComponent( ComponentBase *parent );
/**
* Dtor
@@ -428,7 +428,7 @@ private:
class HSpacerComponent : public Component
{
public:
- HSpacerComponent( ComponentBase *tqparent );
+ HSpacerComponent( ComponentBase *parent );
int widthForHeight( int );
static int RTTI;
@@ -438,7 +438,7 @@ public:
class VSpacerComponent : public Component
{
public:
- VSpacerComponent( ComponentBase *tqparent );
+ VSpacerComponent( ComponentBase *parent );
int heightForWidth( int );
static int RTTI;
@@ -456,8 +456,8 @@ class Item : public TQObject, public KListViewItem, public ComponentBase
Q_OBJECT
TQ_OBJECT
public:
- Item( TQListView *tqparent, TQObject *owner = 0, const char *name = 0 );
- Item( TQListViewItem *tqparent, TQObject *owner = 0, const char *name = 0 );
+ Item( TQListView *parent, TQObject *owner = 0, const char *name = 0 );
+ Item( TQListViewItem *parent, TQObject *owner = 0, const char *name = 0 );
~Item();
void tqrepaint();
@@ -110,7 +110,7 @@ public:
* only be called by the containing item.
* @param rect the new rectangle this component will paint in, relative to the painter
- * passed to the paint() function by the tqparent item.
+ * passed to the paint() function by the parent item.
*/
virtual void tqlayout( const TQRect &rect );
@@ -200,7 +200,7 @@ protected:
* @return true if the size has actually changed, false if it's been set to
* the existing values. if it returns true, you do not need to retqlayout,
- * since the tqparent component will do that for you.
+ * since the parent component will do that for you.
*/
bool setMinWidth( int width );
@@ -209,7 +209,7 @@ protected:
* @return true if the size has actually changed, false if it's been set to
* the existing values. If it returns true, you do not need to retqlayout,
- * since the tqparent component will do that for you.
+ * since the parent component will do that for you.
*/
bool setMinHeight( int height );